@@ -159,7 +159,7 @@ dlvPlot <- function(dat,
                     error = "lines",
                     dotsize = "density",
                     singleColor = "black",
-                    comparisonColors = RColorBrewer::brewer.pal(8, 'Set1'),
+                    comparisonColors = rosetta::opts$get('dlvPlotCompCols'),
                     densityDotBaseSize = 3,
                     normalDotBaseSize = 1,
                     violinAlpha = .2,
