@@ -111,13 +111,13 @@ logRegr <- function(formula, data=NULL, conf.level=.95, digits=2,
                     plot=FALSE,
                     collinearity = FALSE,
                     env=parent.frame(),
-                    predictionColor = viridis::viridis(3)[3],
+                    predictionColor = rosetta::opts$get('viridis3')[3],
                     predictionAlpha = .5,
                     predictionSize = 2,
-                    dataColor = viridis::viridis(3)[1],
+                    dataColor = rosetta::opts$get('viridis3')[1],
                     dataAlpha = .33,
                     dataSize=2,
-                    observedMeansColor = viridis::viridis(3)[2],
+                    observedMeansColor = rosetta::opts$get('viridis3')[2],
                     binObservedMeans = 7,
                     observedMeansSize = 2,
                     observedMeansWidth = NULL,
