@@ -92,7 +92,7 @@ opts$reset <- function(...) {
     } else {
       invalidOptions <-
         !(optionNames %in% names(opts$defaults));
-      stop("Option(s) ", ufs::vecTxtQ(optionNames[invalidOptions]),
+      stop("Option(s) ", vecTxtQ(optionNames[invalidOptions]),
            "' is/are not a valid (i.e. existing) option for rosetta!");
     }
   }
@@ -117,7 +117,14 @@ opts$defaults <-
     tableOutput = c("console", "viewer"),
 
     ### Whether you want extra information, as for debugging
-    debugging = FALSE
+    debugging = FALSE,
+
+    ### RColorBrewer::brewer.pal(8, 'Set1')
+    dlvPlotCompCols = c("#E41A1C", "#377EB8", "#4DAF4A", "#984EA3",
+                        "#FF7F00", "#FFFF33", "#A65628", "#F781BF"),
+
+    ### viridis::viridis(3)
+    viridis3 = c("#440154FF", "#21908CFF", "#FDE725FF")
 
   )
 
